#!/bin/ksh
###############################################################################
# Licensed Materials - Property of IBM
# 5724-T40 IBM License Metric Tool
# 5724-S94 IBM Tivoli Asset Discovery for Distributed
#
# (C) Copyright IBM Corp. 2004, 2010.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

dir_path=$1
backup_dir=back

print_usage()
{
	echo "Incorrect number of arguments"
	echo "usage: install.sh <ILMT|TAD4D-install-dir>"
}

#Checking the parameter
if [ -n "$dir_path" ]
then
	echo "Using ILMT/TAD4D install location: "$dir_path
else 
	print_usage
	exit 1
fi

#Checking whether product.xml file exists in product installation directory
product_xml_file=$dir_path"/product.xml"
if [ -f "$product_xml_file" ]
then
	echo "SUCCESS: product.xml file found in product installation directory"
else
	echo "Error: There is no product.xml file in product installation directory ("$dir_path")"
	echo "Please check whether the given path is correct."
	exit 1
fi

#Checking the software name in product.xml file
prod_name=`cat $product_xml_file | grep Name | awk 'BEGIN { FS = ">" } { print $2 }' | awk 'BEGIN { FS = "<" } { print $1 }'`
if [[ "$prod_name" != "IBM Tivoli License Compliance Manager" ]]
then
	echo "Error: Incorrect product name in product.xml file was found."
	exit 1
fi

#Checking the software version in product.xml file
version=`cat $product_xml_file | grep Version | awk 'BEGIN { FS = ">" } { print $2 }' | awk 'BEGIN { FS = "<" } { print $1 }'`
if [[ "$version" != "7.2.0.1" ]]
then
	echo "Error: Unsupported product version, it is need to be ILMT/TAD4D 7.2.0.1"
	exit 1
fi

#Checking whether it is ILMT or TAD4D installation
lmt_war_path=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war"
tad4d_war_path=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war"
admin__libdir=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war/WEB-INF/lib/"
msghandler_libdir=$dir_path"/eWAS/profiles/AppSrv01/installedApps/cell1/LMT-TAD4D_Agent_message_handler.ear/com.ibm.license.mgmt.msghandler.web.war/WEB-INF/lib/"

if [ -d "$lmt_war_path" ]
then
	echo "ILMT 7.2.0.1 installation was found."
else
	if [ -d "$tad4d_war_path" ]
	then
		echo "TAD4D 7.2.0.1 installation was found."
		admin__libdir=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war/WEB-INF/lib/"
	else
		echo "Error: Cannot locate the product war directory"
		exit 1
	fi
fi

#Checking whether lib directories exists
if [[ ! ( -d "$admin__libdir" && -d "$msghandler_libdir" ) ]]
then
	echo "Error: the msghandler or admin server lib directory cannot be located."
	exit 1
fi

#if the Interim fix was already installed
fix_file=$dir_path"/if1.dat"
if [ -f "$fix_file" ]
then
	echo "Error: Interim Fix 7.2.0.1 IF1 is already installed."
	exit 1
fi

#Stopping the server
srvstop=$dir_path"/cli/srvstop.sh"
if [ -f "$srvstop" ]
then
	echo "Stopping the server ..."
	$srvstop
	return_code=$?
	if [[ $return_code -eq 0 || $return_code -eq 246 ]]
	then
		echo "Server stopped successfully."
	else
		echo "Error: Some problems occur during stopping the server."
		echo "Try to stop the application server manually and try again."
		exit 1
	fi
else
	echo "Error: Cannot find srvstop.sh script to stop the server."
	exit 1
fi

#backup
echo "Creating backup files"
rm -rf $backup_dir
mkdir $backup_dir

if [ $? -ne 0 ]
then
	echo "Error: Cannot create the backup directory."
	exit 1
fi

cp $admin__libdir"com.ibm.license.mgmt.srvfrontend.jar" ./$backup_dir/
cp $admin__libdir"com.ibm.license.mgmt.dao.jar" ./$backup_dir/
cp $admin__libdir"com.ibm.license.mgmt.admin.aggregation.jar" ./$backup_dir/
cp $admin__libdir"com.ibm.license.mgmt.core.jar" ./$backup_dir/
cp $msghandler_libdir"com.ibm.license.mgmt.msghandler.web.jar" ./$backup_dir/

echo "Replacing the jar files"

cp -f com.ibm.license.mgmt.srvfrontend.jar $admin__libdir
cp -f com.ibm.license.mgmt.dao.jar $admin__libdir
cp -f com.ibm.license.mgmt.admin.aggregation.jar $admin__libdir
cp -f com.ibm.license.mgmt.core.jar $admin__libdir

cp -f com.ibm.license.mgmt.srvfrontend.jar $msghandler_libdir
cp -f com.ibm.license.mgmt.dao.jar $msghandler_libdir
cp -f com.ibm.license.mgmt.core.jar $msghandler_libdir
cp -f com.ibm.license.mgmt.msghandler.web.jar $msghandler_libdir

echo "All files replaced"

echo "Creating a 7.2.0.11 InterimFix file."
echo "7.2.0.1 IF1" > $fix_file

echo "Starting the server."
srvstart=$dir_path"/cli/srvstart.sh"
$srvstart
if [[ $? -eq 0 ]]
then
	echo "Server started successfully"
	echo "SUCCESS: ILMT/TAD4D 7.2.0.1 IF1 Interim Fix installation ended successfully."
else
	echo "Warning: Server could not be started. Try to start the application server manually to finish the installation"
	exit 2
fi

exit 0
